package
module
Version:
v0.1.4
Opens a new window with list of versions in this module.
Published: Nov 26, 2021
License: Unlicense
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 5
Opens a new window with list of known importers.
README
¶
go-state
(cd ../go-state-sample && go run .)
curl --unix-socket /tmp/sample.state http://localhost/
curl --unix-socket /tmp/sample.state http://localhost/environ/
curl --unix-socket /tmp/sample.state http://localhost/node/state/
curl --unix-socket /tmp/sample.state 'http://localhost/node/state/?values=true'
curl --unix-socket /tmp/sample.state http://localhost/node/root/
curl --unix-socket /tmp/sample.state 'http://localhost/node/root/?values=true'
curl --unix-socket /tmp/sample.state http://localhost/debug/pprof/
curl --unix-socket /tmp/sample.state 'http://localhost/debug/pprof/goroutine?debug=2'
Documentation
¶
func AddEnvironHandlers(mux Mux)
func AddPProfHandlers(mux Mux)
type Sorted interface {
Count() int
Names() []string
Values() []interface{}
Get(string) interface{}
Set(string, interface{})
Remove(string) interface{}
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.